@@ -15,11 +15,11 @@ isPrintLog = False
 client_id = str(int(time.time() * 1000))
 
 
-def setServerUrl(url='127.0.0.1', port=1883, client_idd=str(int(time.time() * 1000))):
+def setServerUrl(url='127.0.0.1', port=1883, clientID=str(int(time.time() * 1000))):
     global server_url, server_port, client_id
     server_url = url
     server_port = port
-    client_id = client_idd
+    client_id = clientID
 
 
 def setMqttLog(PrintLog=False):
@@ -98,7 +98,6 @@ class Dxr_Publisher:
         topic_list_str = ''
         for item in publish_dit:
             topic_list_str = topic_list_str + item + '\n'
-        print(topic_list_str)
         self.mqttc.publish('/'+client_id+'/topic', retain=True, payload=topic_list_str)
 
     def publish(self, msg):
